Learn R Programming

fractalRegression (version 1.2)

detrend_cov: Detrended Covariance Functional that returns the detrended covariance between two vectors

Description

Detrended Covariance Functional that returns the detrended covariance between two vectors

Usage

detrend_cov(x, y, m)

Arguments

x

a real valued column vector

y

is a real valued column vector

m

is the detrending order