Learn R Programming

fractalRegression (version 1.2)

mBm_mGn: Multifractional Brownian motion and multifractional Gaussian noise

Description

Simulate multifractional Brownian motion and multifractional Gaussian noise.

Usage

mBm_mGn(N, Ht)

Value

The object returned from the function includes:

  • mBm: multifractional Brownian motion

  • mGn: multifractional Gaussian noise

Arguments

N

The length of sample time series to simulate.

Ht

The N by 1 vector of the time evolving H(t).

Details

This is an algorithm that simulates discrete time multifractional Brownian motion and multifractional Gaussian noise, which can useful for testing various functions within the `fractalRegression` package. H(t) should take on any values between 0 and 1. It is meant to capture time varying fractal properties. The example code given below shows a slow evolving Hurst exponent involving a sinusoidal change.

Examples

Run this code

t <- 1:1024
Ht <- 0.5+0.5*(sin(0.0025*pi*t))
sim <- mBm_mGn(1024,Ht)



Run the code above in your browser using DataLab