Learn R Programming

fractalRegression (version 1.2)

poly_residuals: Polynomial Residuals Function that fits a polynomial and returns the residuals

Description

Polynomial Residuals Function that fits a polynomial and returns the residuals

Usage

poly_residuals(yr, m)

Arguments

yr

is a real valued vector

m

is the detrending order